--[[

Interface: 1.4.4.0 1.4.4RC8

Author: GtX | Andy
Date: 16.06.2017
Version: 1.0

Support: http://ls-modcompany.com

Thankyou to:
Rival and Manuel Leithner for insperation from existing scripts.

History:
V 1.0 		@ 	16.06.2017 	- 	Project Started
V 1.0.1 	@ 	01.07.2017 	- 	Added Start Key animation option. 	-  GtX
v 1.0.2		@	07.09.2017	-	Small fixes.	-	GtX
Script redacted for MAZ2000 - AVSR m.t.
]]

realCab ={};

function realCab.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations)
		and	SpecializationUtil.hasSpecialization(Drivable, specializations);
end

function realCab:load(savegame)
	self.isLightsOn = realCab.isLightsOn
	
	self.realCab = {};
	
	local i = 0
	
    while true do
		local onStart = string.format("vehicle.realCab.onStart.startGroup(%d)", i)
		if not hasXMLProperty(self.xmlFile, onStart) then
            break
        end;
		
		local realInside = {}
		
		realInside.floatTime = 1;
		realInside.logoHoldTime = Utils.getNoNil(getXMLFloat(self.xmlFile, onStart.. "#logoDisplayTime"),3000);	--Load hang time of logo. Base defualt 3 Seconds.
		realInside.logoDisplay = Utils.indexToObject(self.components, getXMLString(self.xmlFile, onStart.."#logoDisplay"));	--Displayed before main screen.
		realInside.screenDisplay = Utils.indexToObject(self.components, getXMLString(self.xmlFile, onStart.."#mainScreenDisplay"));	--Displayed after logo.	
		realInside.hudDisplay = Utils.indexToObject(self.components, getXMLString(self.xmlFile, onStart.."#extraScreenDisplay"));	--Displayed with no wait time.
		realInside.warnHoldTime = Utils.getNoNil(getXMLFloat(self.xmlFile, onStart.. "#warnLightDisplayTime"),2000);	--Load hang time of warnLights. Base defualt 2 Seconds.
		realInside.warnLightCheck = Utils.indexToObject(self.components, getXMLString(self.xmlFile, onStart.."#warnLightCheck"));	--Display warn lights for set time on vehicle start.
	
		table.insert(self.realCab, realInside)
		i = i + 1
	end;
	
	self.dayRunningLights = {};
	local drl = "vehicle.realCab.dayRunLights";
	self.dayRunningLights.dayLightsOne = Utils.indexToObject(self.components, getXMLString(self.xmlFile, drl..".drlOne#index"));	--DRL One on engine active.
	self.dayRunningLights.turnOffWithLightsOne = Utils.getNoNil(getXMLBool(self.xmlFile, drl..".drlOne#offWhenLightsActive"), false);	--Show or hide DRL One when Lights are active. - Base defualt is set to off.
	self.dayRunningLights.dayLightsTwo = Utils.indexToObject(self.components, getXMLString(self.xmlFile, drl..".drlTwo#index"));	--DRL Two on engine active.
	self.dayRunningLights.turnOffWithLightsTwo = Utils.getNoNil(getXMLBool(self.xmlFile, drl..".drlTwo#offWhenLightsActive"), false);	--Show or hide DRL Two when Lights are active. - Base defualt is set to off.
	
	self.insideActive = {};
	local active = "vehicle.realCab.onStartAnimations";	
	self.insideActive.animationsOnStart = getXMLString(self.xmlFile, active.. ".onStartAnimation#name");	--Animation name for General onStart Animations.
	self.insideActive.tempAnimations = getXMLString(self.xmlFile, active.. ".tempAnimation#name");	--Animation name for fake Temp gauges
	self.insideActive.coolTime = Utils.getNoNil(getXMLFloat(self.xmlFile, active.. ".tempAnimation#tempCoolSpeed"),1);	--Return modifier for tempAnimationName.
	self.insideActive.aosTime = Utils.getNoNil(getXMLFloat(self.xmlFile, active.. ".onStartAnimation#returnSpeed"),1);	--Return modifier for onStartAnimationName.
	
	self.insideWarning = {};
	local warn = "vehicle.realCab.realWarnLights";	
	self.insideWarning.cruiseLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, warn..".cruiseControl#index"));	--Display a Cruise Control active light.
	self.insideWarning.noDetachLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, warn..".hitchNoDetach#index"));	--Display a flashing warning light if trailer can not be detached.
	self.insideWarning.canConnectLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, warn..".hitchCanConnect#index"));	--Display a ready to attach light when near an implament or trailer.
	self.insideWarning.beaconLights = Utils.indexToObject(self.components, getXMLString(self.xmlFile, warn..".beaconLights#index"));	--Display a static Beacon active light.	
	self.insideWarning.beaconIconFlash = Utils.getNoNil(getXMLBool(self.xmlFile, warn..".beaconLights#flashDashIcon"), false);	--Set if the Becon Active light is static or flashing.	
	self.insideWarning.wipersOnLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, warn..".wipersOn#index"));	--Displays a static Wipers active light if animated wipers are being used.
	self.insideWarning.lowFuelLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, warn..".lowFuel#index"));	--Displays a static Low Fuel light when fuel reaches set level.
	self.insideWarning.fuelLowLevel = Utils.getNoNil(getXMLFloat(self.xmlFile, warn.. ".lowFuel#lowFuelLevel"),80);	--Sets at what level the Low Fuel Light will turn on.
	
	
	self.insideActions = {};
	
	local action = "vehicle.realCab.insideActions";
	self.insideActions.handbrake = getXMLString(self.xmlFile,  action..".handbrake#name");
	self.insideActions.beaconLightsAnim = getXMLString(self.xmlFile,  action..".beaconLightsAnim#name");
	self.insideActions.wipersAnim = getXMLString(self.xmlFile,  action..".wipersAnim#name");
	self.insideActions.honkAnim = getXMLString(self.xmlFile,  action..".honkAnim#name");
	self.insideActions.leftLightAnim = getXMLString(self.xmlFile,  action..".leftLightAnim#name");
	self.insideActions.rightLightAnim = getXMLString(self.xmlFile,  action..".rightLightAnim#name");
    self.insideActions.hazardLightAnim = getXMLString(self.xmlFile,  action..".hazardLightAnim#name");
	self.insideActions.allLightAnim = getXMLString(self.xmlFile,  action..".allLightAnim#name");
	self.insideActions.farLightAnim = getXMLString(self.xmlFile,  action..".farLightAnim#name");
	self.insideActions.CcAnim = getXMLString(self.xmlFile,  action..".CcAnim#name");
	self.insideActions.gasPedal = getXMLString(self.xmlFile,  action..".gasPedal#name");
	self.insideActions.brakePedal = getXMLString(self.xmlFile,  action..".brakePedal#name");
	
	
	self.cabAnimations = {};
	local wipers = "vehicle.realCab.cabAnimations";
	self.cabAnimations.wipersActivated = false;
	self.cabAnimations.wipersAnimation = getXMLString(self.xmlFile, wipers.. ".autoWipers#animationName");	--Autowiper animation name.
	self.cabAnimations.wipersSpeed = Utils.getNoNil(getXMLFloat(self.xmlFile, wipers.. ".autoWipers#moveSpeed"),3);	--Autowiper speed of animations. (Defualt value is preset at 3 as it is a nice speed)
	
	
	self.insideGear = {};
	local autoGear = "vehicle.realCab.gearDisplay";
	self.insideGear.groupIndex = Utils.indexToObject (self.components, getXMLString(self.xmlFile, "vehicle.realCab.gearDisplay#groupIndex"));	--Main Group Index. Hides all displays if Gearbox Addon is active.
	
	if self.insideGear.reverse ~= nil and self.insideGear.groupIndex == nil then
		print("[Error::realCab.lua] reverse#index found but groupIndex is missing from vehicle.xml. Check vehicle.realCab.gearDisplay#groupIndex");
	end;
	if self.insideGear.drive ~= nil and self.insideGear.groupIndex == nil then
		print("[Error::realCab.lua] drive#index found but groupIndex is missing from vehicle.xml. Check vehicle.realCab.gearDisplay#groupIndex");
	end;
	if self.insideGear.neutral ~= nil and self.insideGear.groupIndex == nil then
		print("[Error::realCab.lua] neutral#index found but groupIndex is missing from vehicle.xml. Check vehicle.realCab.gearDisplay#groupIndex");
	end;
	
	self.insideGear.reverse = Utils.indexToObject(self.components, getXMLString(self.xmlFile, autoGear..".reverse#index"));	--Display Reverse Icon when moving back.
	self.insideGear.drive = Utils.indexToObject(self.components, getXMLString(self.xmlFile, autoGear..".drive#index"));	--Display Drive Icon when moving foward.
	self.insideGear.neutral = Utils.indexToObject(self.components, getXMLString(self.xmlFile, autoGear..".neutral#index"));	--Display Netural Icon when stopped.
	
	self.mrGb = {};
	
	local gearboxGroup = "vehicle.realCab.mrGbHud";	
	self.mrGb.groupIndex = Utils.indexToObject (self.components, getXMLString(self.xmlFile, "vehicle.realCab.mrGbHud#groupIndex"));	--Main Group Index. Hides all MRGB displays if Gearbox Addon is disabled.
	
	if self.mrGb.gearNumber ~= nil and self.mrGb.groupIndex == nil then
		print("[Error::realCab.lua] gearNumbers found but groupIndex missing from vehicle.xml. Check vehicle.realCab.mrGbHud#groupIndex");
	end;
	if self.mrGb.reverseIconIndex ~= nil and self.mrGb.groupIndex == nil then
		print("[Error::realCab.lua] iconIndex#reverse found but groupIndex missing from vehicle.xml. Check vehicle.realCab.mrGbHud#groupIndex");
	end;
	if self.mrGb.holdIconIndex ~= nil and self.mrGb.groupIndex == nil then
		print("[Error::realCab.lua] iconIndex#autoHold found but groupIndex missing from vehicle.xml. Check vehicle.realCab.mrGbHud#groupIndex");
	end;
	
	self.mrGb.gearNumber = VehicleHudUtils.loadHud(self, self.xmlFile, "gearNumbers", gearboxGroup);	--Adds a Digital ONLY display for MrGB Mod Gear Number using the standard indoorHud format.
	self.mrGb.reverseIconIndex = Utils.indexToObject (self.components, getXMLString(self.xmlFile, "vehicle.realCab.mrGbHud.iconIndex#reverse"));	--"Reverse" Icon Index (Displayed when Reverse is activated in MRGBM).
	self.mrGb.holdIconIndex = Utils.indexToObject (self.components, getXMLString(self.xmlFile, "vehicle.realCab.mrGbHud.iconIndex#autoHold"));	--"Netural" Icon Index (Displayed when Netural is activated in MRGBM).
	
	if self.mrGb.gearNumber ~= nil and self.mrGb.reverseIconIndex == nil then
		print("[Error::realCab.lua] gearNumbers found but iconIndex#reverse is missing from the vehicle.xml. Check vehicle.realCab.mrGbHud.iconIndex#reverse");
	end;
	if self.mrGb.gearNumber ~= nil and self.mrGb.holdIconIndex == nil then
		print("[Error::realCab.lua] gearNumbers found but iconIndex#autoHold is missing from the vehicle.xml. Check vehicle.realCab.mrGbHud.iconIndex#autoHold");
	end;
	
	self.generalHud = {};
	local generalGroup = "vehicle.realCab.hudDisplay";
	self.generalHud.bcAnimations = VehicleHudUtils.loadHud(self, self.xmlFile, "brakeCompressor", generalGroup);	--Adds a Analogue or Digital display for brakeCompressor fill volume using the standard indoorHud format.
	
end;
	
function realCab:update(dt)
	if self.isClient then
	
--**********************************************************************************************************	
-- realCab onStart
--**********************************************************************************************************
	
		for i=1, table.getn(self.realCab) do
			local realInside = self.realCab[i]
			
			if realInside.hudDisplay ~= nil then
				if self.isMotorStarted	
					then setVisibility(realInside.hudDisplay, true);
					else setVisibility(realInside.hudDisplay, false);
				end;
			end;
			
			if realInside.logoDisplay ~= nil and realInside.screenDisplay ~= nil then
				if self.isMotorStarted then 
					if realInside.floatTime < realInside.logoHoldTime 
						then setVisibility(realInside.logoDisplay, true); setVisibility(realInside.screenDisplay, false);
					end;
					if realInside.floatTime < (realInside.logoHoldTime + realInside.logoHoldTime) and realInside.floatTime > realInside.logoHoldTime
						then setVisibility(realInside.logoDisplay, false); setVisibility(realInside.screenDisplay, true);
					end;
					realInside.floatTime = realInside.floatTime + dt;
					else realInside.floatTime = 1; setVisibility(realInside.logoDisplay, false); setVisibility(realInside.screenDisplay, false);
				end;
			end;
			
			if realInside.warnLightCheck ~= nil then
				if self.isMotorStarted then 
					if realInside.floatTime < realInside.warnHoldTime 
						then setVisibility(realInside.warnLightCheck, true);
					end;
					if realInside.floatTime < (realInside.warnHoldTime + realInside.warnHoldTime) and realInside.floatTime > realInside.warnHoldTime
						then setVisibility(realInside.warnLightCheck, false);
					end;
					realInside.floatTime = realInside.floatTime + dt;
					else realInside.floatTime = 1; setVisibility(realInside.warnLightCheck, false);
				end;
			end;
		end;
		
--**********************************************************************************************************	
-- realCab dayLights
--**********************************************************************************************************
			
			if self.dayRunningLights.dayLightsOne ~= nil then
				local dayLightsOffOne = self.isMotorStarted and self:isLightsOn() and self.dayRunningLights.turnOffWithLightsOne
				if self.dayRunningLights.turnOffWithLightsOne == false then				
					else if self.isMotorStarted and dayLightsOffOne then
						setVisibility(self.dayRunningLights.dayLightsOne, false);
					else 
						setVisibility(self.dayRunningLights.dayLightsOne, true);
					end;
				end;
				if self.isMotorStarted and not dayLightsOffOne then
					setVisibility(self.dayRunningLights.dayLightsOne, true);
				else 
					setVisibility(self.dayRunningLights.dayLightsOne, false);
				end;
			end;
			if self.dayRunningLights.dayLightsTwo ~= nil then
				local dayLightsOffTwo = self.isMotorStarted and self:isLightsOn() and self.dayRunningLights.turnOffWithLightsTwo
				if self.dayRunningLights.turnOffWithLightsTwo == false then
					else if self.isMotorStarted and dayLightsOffTwo then
						setVisibility(self.dayRunningLights.dayLightsTwo, false);
					else 
						setVisibility(self.dayRunningLights.dayLightsTwo, true);
					end;
				end;
				if self.isMotorStarted and not dayLightsOffTwo then
					setVisibility(self.dayRunningLights.dayLightsTwo, true);
				else 
					setVisibility(self.dayRunningLights.dayLightsTwo, false);
				end;
			end;

--**********************************************************************************************************	
-- realCab gearDisplay
--**********************************************************************************************************
		if self:getIsActive() then
			local gearboxIsOn = false;
			if self.mrGbMS ~= nil then
				gearboxIsOn = self:mrGbMGetIsOnOff()
			end;

			if self.isMotorStarted and gearboxIsOn then
				if self.mrGb.groupIndex ~= nil then
					setVisibility(self.mrGb.groupIndex, true);
				end;
				if self.insideGear.groupIndex ~= nil then
					setVisibility(self.insideGear.groupIndex, false);
				end;				
				if self.mrGb.reverseIconIndex ~= nil then
					if self:mrGbMGetReverseActive() then
						setVisibility(self.mrGb.reverseIconIndex, true);
					else 
						setVisibility(self.mrGb.reverseIconIndex, false);
					end;
				end;
				if self.mrGb.holdIconIndex ~= nil then
					if self:mrGbMGetNeutralActive() then
						setVisibility(self.mrGb.holdIconIndex, true);
					else 
						setVisibility(self.mrGb.holdIconIndex, false);
					end;
				end;
				if self.insideGear.neutral ~= nil then
					setVisibility(self.insideGear.neutral, false);
				end;
				if self.insideGear.reverse ~= nil then
					setVisibility(self.insideGear.reverse, false);
				end;
				if self.insideGear.drive ~= nil then
					setVisibility(self.insideGear.drive, false);
				end;
				
			elseif self.isMotorStarted and not gearboxIsOn then
				if self.insideGear.groupIndex ~= nil then
					setVisibility(self.insideGear.groupIndex, true);
				end;
				if self.mrGb.groupIndex ~= nil then
					setVisibility(self.mrGb.groupIndex, false);
				end;
				if self.mrGb.reverseIconIndex ~= nil then
					setVisibility(self.mrGb.reverseIconIndex, false);
				end;
				if self.mrGb.holdIconIndex ~= nil then
					setVisibility(self.mrGb.holdIconIndex, false);
				end;
				if self:getLastSpeed() * self.speedDisplayScale < 1 and self.movingDirection == 0 then
					if self.insideGear.neutral ~= nil then
						setVisibility(self.insideGear.neutral, true);
					end;
				elseif self:getLastSpeed() * self.speedDisplayScale > 1 and self.movingDirection < 0 then
					if self.insideGear.reverse ~= nil then
						setVisibility(self.insideGear.reverse, true);
					end;
				elseif self:getLastSpeed() * self.speedDisplayScale > 1 and self.movingDirection > 0 then
					if self.insideGear.drive ~= nil then
						setVisibility(self.insideGear.drive, true);
					end;
				else
					if self.insideGear.neutral ~= nil then
						setVisibility(self.insideGear.neutral, false);
					end;
					if self.insideGear.reverse ~= nil then
						setVisibility(self.insideGear.reverse, false);
					end;
					if self.insideGear.drive ~= nil then
						setVisibility(self.insideGear.drive, false);
					end;
				end;
			end;
			
		end;

--**********************************************************************************************************	
-- realCab onStartAnimations
--**********************************************************************************************************
		
		if self.insideActive.animationsOnStart ~= nil then
			if self.isMotorStarted then
				self:playAnimation(self.insideActive.animationsOnStart, 1, self:getAnimationTime(self.insideActive.animationsOnStart), true);
			else
				self:playAnimation(self.insideActive.animationsOnStart, -self.insideActive.aosTime, self:getAnimationTime(self.insideActive.animationsOnStart), true);
			end;
		end;
			
		if self.insideActive.tempAnimations ~= nil then
			if self.isMotorStarted then
				self:playAnimation(self.insideActive.tempAnimations, 1, self:getAnimationTime(self.insideActive.tempAnimations), true);
			else
				self:playAnimation(self.insideActive.tempAnimations, -self.insideActive.coolTime, self:getAnimationTime(self.insideActive.tempAnimations), true);
			end;
		end;
		
--**********************************************************************************************************	
-- realCab warnLights
--**********************************************************************************************************
		
		if self.insideWarning.cruiseLight ~= nil then
			if self:getIsActive() then
				if self.cruiseControl.state == Drivable.CRUISECONTROL_STATE_OFF then
					setVisibility(self.insideWarning.cruiseLight, false);
				else
					if self.isMotorStarted then
						setVisibility(self.insideWarning.cruiseLight, true);
					end;
				end;
			end;
		end;
		
		if self.insideWarning.noDetachLight ~= nil and self.attacherJoints ~= nil then
		local warnFlash = Utils.clamp(math.cos( 9.0 * (g_currentMission.time/1000) ) + 0.2, 0, 1);
			if self.showDetachingNotAllowedTime > 0 and warnFlash == 0 then
				setVisibility(self.insideWarning.noDetachLight, true);
			else 
				setVisibility(self.insideWarning.noDetachLight, false);
			end;
		end;
		
		if self.insideWarning.canConnectLight ~= nil and self.attacherJoints ~= nil then
			if g_currentMission.attachableInMountRange == nil then
				setVisibility(self.insideWarning.canConnectLight, false);
			else 
				setVisibility(self.insideWarning.canConnectLight, true);
			end;
		end;
		
		if self.insideWarning.beaconLights ~= nil then
			local warnFlash = Utils.clamp(math.cos( 9.0 * (g_currentMission.time/1000) ) + 0.2, 0, 1);
			local flashIcon = self.insideWarning.beaconIconFlash;
			if self:getIsActive() then
				if self.beaconLightsActive and warnFlash == 0 and flashIcon then
					setVisibility(self.insideWarning.beaconLights, true);
				elseif self.beaconLightsActive and not flashIcon then
					setVisibility(self.insideWarning.beaconLights, true);
				else
					setVisibility(self.insideWarning.beaconLights, false);
				end;
			end;
		end;

		local wiperLightOn = false;
		if self.cabAnimations.wipersAnimation ~= nil then
			wiperLightOn = self.isMotorStarted and self.cabAnimations.wipersActivated == true
		end;
			
		if self.insideWarning.wipersOnLight ~= nil then
			if wiperLightOn then
				setVisibility(self.insideWarning.wipersOnLight, true);
			else
				setVisibility(self.insideWarning.wipersOnLight, false);
			end;
		end;
		
		if self.insideWarning.lowFuelLight ~= nil then
			if self.isMotorStarted then
				if self.fuelFillLevel <= self.insideWarning.fuelLowLevel then
					setVisibility(self.insideWarning.lowFuelLight, true);
				else
					setVisibility(self.insideWarning.lowFuelLight, false);
				end;
			elseif not self.isMotorStarted then
				setVisibility(self.insideWarning.lowFuelLight, false);
			end;
		end;
		
--**********************************************************************************************************	
-- realCab actionAnimations
--**********************************************************************************************************
		if self.insideActions.beaconLightsAnim ~= nil then
			local warnFlash = Utils.clamp(math.cos( 9.0 * (g_currentMission.time/1000) ) + 0.2, 0, 1);
			local flashIcon = self.insideActions.beaconIconFlash;
			if self:getIsActive() then
				if self.beaconLightsActive and warnFlash == 0 and flashIcon then
					self:playAnimation(self.insideActions.beaconLightsAnim, 3, self:getAnimationTime(self.insideActions.beaconLightsAnim), true);
				elseif self.beaconLightsActive and not flashIcon then
					self:playAnimation(self.insideActions.beaconLightsAnim, 3, self:getAnimationTime(self.insideActions.beaconLightsAnim), true);
				else
				    self:playAnimation(self.insideActions.beaconLightsAnim, -3, self:getAnimationTime(self.insideActions.beaconLightsAnim), true);
			    end;
			end;
		end;
		
		if self.insideActions.wipersAnim ~= nil then	
			if self:getIsActive() then
			    if self.cabAnimations.wipersActivated == true then
				    self:playAnimation(self.insideActions.wipersAnim, 3, self:getAnimationTime(self.insideActions.wipersAnim), true);
			    else
				    self:playAnimation(self.insideActions.wipersAnim, -3, self:getAnimationTime(self.insideActions.wipersAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.brakePedal ~= nil then	
			if self:getIsActive() then
			    if self.brakeLightsVisibility then
				    self:playAnimation(self.insideActions.brakePedal, 3, self:getAnimationTime(self.insideActions.brakePedal), true);
			    else
				    self:playAnimation(self.insideActions.brakePedal, -3, self:getAnimationTime(self.insideActions.brakePedal), true);
			    end;
			end;
		end
		
		if self.insideActions.honkAnim ~= nil then	
			if self:getIsActive() then
			    if  self.sampleHonk.isPlaying then
				    self:playAnimation(self.insideActions.honkAnim, 3, self:getAnimationTime(self.insideActions.honkAnim), true);
			    else
				    self:playAnimation(self.insideActions.honkAnim, -3, self:getAnimationTime(self.insideActions.honkAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.leftLightAnim ~= nil then	
			if self:getIsActive() then
			    if self.turnLightState == Lights.TURNLIGHT_LEFT then
				    self:playAnimation(self.insideActions.leftLightAnim, 3, self:getAnimationTime(self.insideActions.leftLightAnim), true);
			    else
				    self:playAnimation(self.insideActions.leftLightAnim, -3, self:getAnimationTime(self.insideActions.leftLightAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.rightLightAnim ~= nil then	
			if self:getIsActive() then
			    if self.turnLightState == Lights.TURNLIGHT_RIGHT then
				    self:playAnimation(self.insideActions.rightLightAnim, 3, self:getAnimationTime(self.insideActions.rightLightAnim), true);
			    else
				    self:playAnimation(self.insideActions.rightLightAnim, -3, self:getAnimationTime(self.insideActions.rightLightAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.hazardLightAnim ~= nil then	
			if self:getIsActive() then
			    if self.turnLightState == Lights.TURNLIGHT_HAZARD then
				    self:playAnimation(self.insideActions.hazardLightAnim, 3, self:getAnimationTime(self.insideActions.hazardLightAnim), true);
			    else
				    self:playAnimation(self.insideActions.hazardLightAnim, -3, self:getAnimationTime(self.insideActions.hazardLightAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.allLightAnim ~= nil then	
			if self:getIsActive() then
			    if self.lightsTypesMask > 0 then
				    self:playAnimation(self.insideActions.allLightAnim, 3, self:getAnimationTime(self.insideActions.allLightAnim), true);
			    else
				    self:playAnimation(self.insideActions.allLightAnim, -3, self:getAnimationTime(self.insideActions.allLightAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.farLightAnim ~= nil then	
			if self:getIsActive() then
			    if self.lightsTypesMask == 3 then
				    self:playAnimation(self.insideActions.farLightAnim, 3, self:getAnimationTime(self.insideActions.farLightAnim), true);
			    else
				    self:playAnimation(self.insideActions.farLightAnim, -3, self:getAnimationTime(self.insideActions.farLightAnim), true);
			    end;
			end;
		end
		
		if self.insideActions.CcAnim ~= nil then	
			if self:getIsActive() then
			    if self.cruiseControl.state == Drivable.CRUISECONTROL_STATE_OFF then
				    self:playAnimation(self.insideActions.CcAnim, -3, self:getAnimationTime(self.insideActions.CcAnim), true);
			    else
				    if self.isMotorStarted then
				        self:playAnimation(self.insideActions.CcAnim, 3, self:getAnimationTime(self.insideActions.CcAnim), true);
				    end;
			    end;
			end;
		end;
		
		local gasPedalAxis = 0;
        gasPedalForward = InputBinding.getInputAxis(InputBinding.AXIS_ACCELERATE_VEHICLE);
		gasPedalBackward = InputBinding.getInputAxis(InputBinding.AXIS_BRAKE_VEHICLE);
		
		if self.insideActions.gasPedal ~= nil then	
			if self:getIsActive() then
			    if gasPedalForward < 0 and not self.brakeLightsVisibility or gasPedalBackward < 0 and not self.brakeLightsVisibility  then
				    self:playAnimation(self.insideActions.gasPedal, 3, self:getAnimationTime(self.insideActions.gasPedal), true);
			    else
				    self:playAnimation(self.insideActions.gasPedal, -3, self:getAnimationTime(self.insideActions.gasPedal), true);
			    end;
			end;
		end
		
		local gearboxIsOn = false;
		if self.mrGbMS ~= nil then
			gearboxIsOn = self:mrGbMGetIsOnOff()
		end;
		
		if self.isMotorStarted and gearboxIsOn then
			if self.insideActions.handbrake ~= nil then
				if self:mrGbMGetNeutralActive() then
					self:playAnimation(self.insideActions.handbrake, 3, self:getAnimationTime(self.insideActions.handbrake), true);
				else
					self:playAnimation(self.insideActions.handbrake, -3, self:getAnimationTime(self.insideActions.handbrake), true);
				end;
			end;
			
		elseif self.isMotorStarted and not gearboxIsOn then
			if self.insideActions.handbrake ~= nil then
				if self.movingDirection == 0 then
					self:playAnimation(self.insideActions.handbrake, 3, self:getAnimationTime(self.insideActions.handbrake), true);
				else
					self:playAnimation(self.insideActions.handbrake, -3, self:getAnimationTime(self.insideActions.handbrake), true);
				end;
			end;
		
		elseif not self.isMotorStarted and self.movingDirection == 0 then
			if self.insideActions.handbrake ~= nil then
				self:playAnimation(self.insideActions.handbrake, 3, self:getAnimationTime(self.insideActions.handbrake), true);
			end;
		end;
	end;	
end;

function realCab:updateTick(dt)
	local gearboxIsOn = false;
	if self.mrGbMS ~= nil then
		gearboxIsOn = self:mrGbMGetIsOnOff()
	end;

	if self.isClient then
		if self:getIsMotorStarted() then
			if self.generalHud.bcAnimations ~= nil then
				VehicleHudUtils.setHudValue(self, self.generalHud.bcAnimations, self.brakeCompressor.fillLevel, self.brakeCompressor.capacity);
			end;
			if self.mrGb.gearNumber ~= nil and self.mrGb.groupIndex ~= nil and gearboxIsOn then
				VehicleHudUtils.setHudValue(self, self.mrGb.gearNumber, self:mrGbMGetGearNumber());
			end;
		end;
	end;
	
	if self.cabAnimations.wipersAnimation ~= nil then
		if self:getIsActive() and self.isMotorStarted then
			if self.cabAnimations.wipersActivated then
				if not self:getIsAnimationPlaying(self.cabAnimations.wipersAnimation) then
					self:playAnimation(self.cabAnimations.wipersAnimation, self.cabAnimations.wipersSpeed, 0, true);
				end;
			end;
			
			if g_currentMission.environment.lastRainScale > 0.1 and g_currentMission.environment.timeSinceLastRain < 30 then
				if not self.cabAnimations.wipersActivated then
					self:playAnimation(self.cabAnimations.wipersAnimation, self.cabAnimations.wipersSpeed, Utils.clamp(self:getAnimationTime(self.cabAnimations.wipersAnimation), 0, 1), true);
					self.cabAnimations.wipersActivated = true;
				end;
			else
				if self.cabAnimations.wipersActivated then
					self:setAnimationStopTime(self.cabAnimations.wipersAnimation, 1);
					self.cabAnimations.wipersActivated = false;
				end;
			end;
		end;
	end;
end;

function realCab:isLightsOn()
	local drlOn = true
	if self.lightsTypesMask == 0 then
		drlOn = false
	end;
	return drlOn
end;

function realCab:stopMotor()
	if self.generalHud.bcAnimations ~= nil then
		VehicleHudUtils.setHudValue(self, self.generalHud.bcAnimations, 0, self.brakeCompressor.capacity);
	end;
	if self.mrGb.GearNumber ~= nil then
		VehicleHudUtils.setHudValue(self, self.mrGb.GearNumber, 0, 0);
	end;
end;

--Unused Functions--

function realCab:readStream(streamId, connection)
end;

function realCab:writeStream(streamId, connection)
end;

function realCab:draw()
end;
	
function realCab:delete()
end;

function realCab:keyEvent(unicode, sym, modifier, isDown)
end;

function realCab:mouseEvent(posX, posY, isDown, isUp, button)
end;